'use strict'

import React, { PropTypes } from 'react';
import animate from 'animateplus';


export default class PlayPause extends React.Component {


  static propTypes = {
    play: PropTypes.bool.isRequired,
    initialMode: PropTypes.string,
    pathPlay: PropTypes.string,
    pathPause: PropTypes.string,
    width: PropTypes.number,
    height: PropTypes.number,
    fill: PropTypes.string,
    stroke: PropTypes.string,
    strokeOpacity: PropTypes.string,
    style: PropTypes.object
  };


  static defaultProps = {
    initialMode: 'pause',
    pathPlay: 'M 5,2 L18,10 L18,26 L5,34 z M 18,10 L31,18 L31,18 L18,26 Z',
    pathPause: 'M 5,2 L13.5,2 13.5,34 5,34 z M 22.5,2 L31,2 31,34 22.5,34 z',
    width: 250,
    height: 250,
    fill: '#fff',
    stroke: '#000',
    strokeOpacity: '.15'
  };


  constructor(props) {
    super(props);

    this.state = this.__getInitialState();
  }


  __getInitialState() {
    return {}
  }


  componentDidUpdate() {
    this._handleAnimate();
  }


  _handleAnimate() {
    const { pathPlay, pathPause } = this.props;

    const optPoints = {
      el: [this.refs.pathMain, this.refs.pathStroke],
      d: (this.props.play) ? [pathPlay, pathPause] : [pathPause, pathPlay],
      duration: 200,
      easing: 'easeOutCubic'
    }

    animate(optPoints);
  }


  render() {
    const { pathPlay, pathPause, width, height, initialMode, fill, stroke, strokeOpacity, style } = this.props;

    return(
      <svg
        version="1.1"
        xmlns="http://www.w3.org/2000/svg"
        x="0"
        y="0"
        viewBox="0 0 36 36"
        { ...{ width, height, style } }
      >
        <g
          stroke={ stroke }
          strokeWidth="2"
          strokeOpacity={ strokeOpacity }
        >
          <path
            ref="pathStroke"
            d={ (initialMode === 'pause') ? pathPlay : pathPause }
          />
        </g>
        <g fill={ fill }>
          <path
            ref="pathMain"
            d={ (initialMode === 'pause') ? pathPlay : pathPause }
          />
        </g>
      </svg>
    );
  }


}
